==> gcc-g++-4.3.1.tar.bz2: gcc-4.3.1/libstdc++-v3/testsuite/23_containers/vector/bool/capacity/29134.cc <==
// Copyright (C) 2006, 2007 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without Pred the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
// USA.

// 23.2.5 class vector<bool> [lib.vector.bool]

#include <vector>
#include <limits>
#include <testsuite_hooks.h>

// libstdc++/29134
void test01()
{
  bool test __attribute__((unused)) = true;

  using std::vector;
  using std::numeric_limits;

#ifndef _GLIBCXX_DEBUG
  using std::_S_word_bit;
#else
  using std::_GLIBCXX_STD_D::_S_word_bit;
#endif

  // Actually, vector<bool> is special, see libstdc++/31370.
  vector<bool> vb;
  typedef vector<bool>::difference_type difference_type;
  typedef vector<bool>::size_type size_type;
  VERIFY( vb.max_size()
	  == size_type(numeric_limits<difference_type>::max()
		       - int(_S_word_bit) + 1) );
}

int main()
{
  test01();
  return 0;
}

==> gcc-g++-4.5.3.tar.bz2: gcc-4.5.3/libstdc++-v3/testsuite/23_containers/vector/bool/capacity/29134.cc <==
// Copyright (C) 2006, 2007, 2009, 2010 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without Pred the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.

// 23.2.5 class vector<bool> [lib.vector.bool]

#include <vector>
#include <limits>
#include <testsuite_hooks.h>

// libstdc++/29134
void test01()
{
  bool test __attribute__((unused)) = true;

  using std::vector;
  using std::numeric_limits;

#ifdef _GLIBCXX_DEBUG
  using std::_GLIBCXX_STD_D::_S_word_bit;
#elif defined(_GLIBCXX_PROFILE)
  using std::_GLIBCXX_STD_PR::_S_word_bit;
#else
  using std::_S_word_bit;
#endif

  // Actually, vector<bool> is special, see libstdc++/31370.
  vector<bool> vb;
  typedef vector<bool>::difference_type difference_type;
  typedef vector<bool>::size_type size_type;
  VERIFY( vb.max_size()
	  == size_type(numeric_limits<difference_type>::max()
		       - int(_S_word_bit) + 1) );
}

int main()
{
  test01();
  return 0;
}
